#!/usr/bin/env python
"""This script runs the whole app"""

from os import environ
from address import Address
from ipify import IpIfy
from jsonip import JsonIp
from mailer import Mailer

address = Address('address.txt')
try:
    user = environ["GMAIL_USER"]
    pwd = environ["GMAIL_PASS"]
except KeyError as err:
    print('You need to add the environment variable: %s' % err)
    quit(1)
try:
    provider = environ["IP_PROVIDER"]
    if provider == 'ipify':
        provider = IpIfy()
    else:
        raise KeyError
except KeyError:
    provider = JsonIp()

ip = provider.get_ip(provider.get_response())

if ip != address.load():
    address.save(ip)
    data = {'user': user, 'pwd': pwd, 'subject': 'IP Teller', 'body': 'Your IP changed to: %s' % ip}
    deliver = Mailer().send(data)



#!/usr/bin/env python

import logging
import requests


class ProviderIp(object):
    def __init__(self):
        self.url = ''

    def get_response(self):
        try:
            return requests.get(self.url).json()
        except ValueError as err:
            logging.exception(err)



#!/usr/bin/env python

import logging
import smtplib


class Mailer(object):
    @staticmethod
    def send(data):
        host = "smtp.gmail.com"
        port = 465
        try:
            server = smtplib.SMTP_SSL(host, port)
            server.login(data['user'], data['pwd'])
            server.sendmail(data['user'], data['user'], Mailer.message(data))
            server.close()
            logging.info('Notification of the new IP sent')
        except smtplib.SMTPAuthenticationError as error:
            logging.exception('Authentication error:' + error.smtp_error)
            quit(0)
        except ValueError as error:
            logging.exception(error.message)
            quit(0)

    @staticmethod
    def message(data):
        return """\
From: %s
To: %s
Subject: %s

%s
""" % (data['user'], data['user'], data['subject'], data['body'])



from distutils.core import setup
import ipteller

setup(
    name=ipteller.__name__,
    version=ipteller.__version__,
    description='Sends an email when your IP address changes',
    author=ipteller.__author__,
    author_email=ipteller.__email__,
    url=ipteller.__url__,
    license='MIT',
    platforms='unix',
    classifiers=[
        "Programming Language :: Python :: 2.7",
        "Operating System :: Unix",
        "Topic :: Internet",
        "Topic :: Utilities",
    ],
    packages=['ipteller'],
    tests_require=['behave'],
    install_requires=['requests'],
    zip_safe=False
)


#!/usr/bin/env python

from providerip import ProviderIp


class JsonIp(ProviderIp):
    def __init__(self):
        ProviderIp.__init__(self)
        self.url = 'https://jsonip.com/'

    @staticmethod
    def get_ip(uri):
        return uri["ip"]



#!/usr/bin/env python

import logging
import os.path


class Address(object):
    def __init__(self, storage):
        if not os.path.exists(storage):
            logging.warning('Creating file: ' + storage)
            file(storage, 'w').close()
        self.storage = storage

    def load(self):
        stored_ip = open(self.storage)
        return stored_ip.readline()

    def save(self, ip):
        stored_ip = open(self.storage, 'w')
        stored_ip.write(ip)
        stored_ip.close()
